@@ -106,6 +106,11 @@ NumericVector cpp_dbetapr(
     const bool& log_prob = false
   ) {
   
+  if (std::min({x.length(), alpha.length(),
+                beta.length(), sigma.length()}) < 1) {
+    return NumericVector(0);
+  }
+  
   int Nmax = std::max({
     x.length(),
     alpha.length(),
@@ -141,6 +146,11 @@ NumericVector cpp_pbetapr(
     const bool& log_prob = false
   ) {
   
+  if (std::min({x.length(), alpha.length(),
+                beta.length(), sigma.length()}) < 1) {
+    return NumericVector(0);
+  }
+  
   int Nmax = std::max({
     x.length(),
     alpha.length(),
@@ -179,6 +189,11 @@ NumericVector cpp_qbetapr(
     const bool& log_prob = false
   ) {
   
+  if (std::min({p.length(), alpha.length(),
+                beta.length(), sigma.length()}) < 1) {
+    return NumericVector(0);
+  }
+  
   int Nmax = std::max({
     p.length(),
     alpha.length(),
@@ -216,6 +231,11 @@ NumericVector cpp_rbetapr(
     const NumericVector& sigma
   ) {
   
+  if (std::min({alpha.length(), beta.length(), sigma.length()}) < 1) {
+    Rcpp::warning("NAs produced");
+    return NumericVector(n, NA_REAL);
+  }
+  
   NumericVector x(n);
   
   bool throw_warning = false;
